@@ -10,7 +10,7 @@ from warnings import warn
 
 from logilab.common.decorators import cached
 
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 from cubicweb.entities import AnyEntity, fetch_config
 from cubicweb.entities.adapters import ITreeAdapter
 
