@@ -13,10 +13,11 @@ class AutomaticWebTest(AutomaticWebTest):
     def list_startup_views(self):
         return ('stats', 'versionsinfo')
 
-    def post_populate(self, cursor):
-        self.commit()
-        for version in cursor.execute('Version X').entities():
+    def post_populate(self, cnx):
+        cnx.commit()
+        for version in cnx.execute('Version X').entities():
             version.cw_adapt_to('IWorkflowable').change_state('published')
+        cnx.commit()
 
 
 class VersionCalendarViews(CubicWebTC):
