@@ -42,21 +42,22 @@ def security_tc_init_project(tc, cnx, name, user_prefix=None):
 
 class TrackerTCMixIn(object):
 
-    def create_project(self, req, pname, description=None):
-        return req.execute(*create_project_rql(pname, description))
+    def create_project(self, cnx, pname, description=None):
+        return cnx.execute(*create_project_rql(pname, description))
 
-    def create_version(self, req, num, pname='cubicweb'):
-        return req.execute(*create_version_rql(num, pname))
+    def create_version(self, cnx, num, pname='cubicweb'):
+        return cnx.execute(*create_version_rql(num, pname))
 
-    def create_ticket(self, req, title, vnum=None, pname='cubicweb'):
-        rset = req.execute(*create_ticket_rql(title, pname))
+    def create_ticket(self, cnx, title, vnum=None, pname='cubicweb'):
+        rset = cnx.execute(*create_ticket_rql(title, pname))
         if vnum:
-            req.execute('SET X done_in V WHERE X eid %(x)s, V num %(num)s',
+            cnx.execute('SET X done_in V WHERE X eid %(x)s, V num %(num)s',
                         {'x': rset[0][0], 'num': vnum})
         return rset
 
 
 class TrackerBaseTC(TrackerTCMixIn, CubicWebTC):
+
     def setup_database(self):
         with self.admin_access.client_cnx() as cnx:
             self.cubicweb = cnx.create_entity('Project', name=u'cubicweb',
@@ -65,12 +66,12 @@ class TrackerBaseTC(TrackerTCMixIn, CubicWebTC):
 
     def tearDown(self):
         CubicWebTC.tearDown(self)
-        for sessionid in list(self.repo._sessions):
-            self.repo.close(sessionid)
+        self.repo.close_sessions()
 
 
 class SecurityTC(TrackerTCMixIn, CubicWebTC):
     repo_config = BaseApptestConfiguration('data')
+
     def setUp(self):
         """
             User created:
@@ -92,8 +93,7 @@ class SecurityTC(TrackerTCMixIn, CubicWebTC):
 
     def tearDown(self):
         CubicWebTC.tearDown(self)
-        for sessionid in list(self.repo._sessions):
-            self.repo.close(sessionid)
+        self.repo.close_sessions()
 
     def _test_tr_fail(self, user, x, trname):
         with self.new_access(user).client_cnx() as cnx:
