@@ -10,7 +10,7 @@ _ = unicode
 from logilab.mtconverter import xml_escape
 
 from cubicweb.view import EntityView
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 
 class LinkedDataView(EntityView):
     __regid__ = 'linked_data'
