@@ -8,9 +8,10 @@ __docformat__ = "restructuredtext en"
 
 from datetime import datetime
 
-from cubicweb.selectors import is_instance, match_transition, attribute_edited
-from cubicweb.web import uicfg, formfields, eid_param
-from cubicweb.web.views import workflow, editviews
+from cubicweb.predicates import is_instance, match_transition, attribute_edited
+from cubicweb.web import formfields, eid_param
+from cubicweb.web.form import FieldNotFound
+from cubicweb.web.views import uicfg, workflow, editviews
 from cubicweb.web.views.autoform import AutomaticEntityForm
 
 
@@ -36,14 +37,20 @@ def ticket_subj_rel_choices(rtype, version_state_restr):
         # it isn't, check if the entity provides a method to get correct values
         vocab = field.relvoc_init(form)
         if not entity.has_eid():
-            try:
+            if ('concerns', 'subject') in form.linked_to:
+                # user clicked on custom LinkToEntityAction
                 peids = form.linked_to['concerns', 'subject']
-            except KeyError:
-                # copy
-                cteid = form.field_by_name(eid_param('__cloned_eid', entity.eid)).value
-                peid = form._cw.entity_from_eid(cteid, 'Ticket').project.eid
+                peid = peids[0] if peids else None
             else:
-                peid = peids and peids[0]
+                try:
+                    # '__cloned_eid:<X>' is set by CopyFormView
+                    cteid = form.field_by_name(eid_param('__cloned_eid', entity.eid)).value
+                    peid = form._cw.entity_from_eid(cteid, 'Ticket').project.eid
+                except FieldNotFound:
+                    # plain old "<baseurl>/add/Ticket"
+                    # XXX needs a proper widget (possibly with JS voodoo),
+                    # instead of an empty list.
+                    peid = None
             veid = None
         else:
             peid = entity.project.eid
