@@ -13,17 +13,15 @@ from logilab.mtconverter import xml_escape
 from logilab.common import table as _table
 
 from cubicweb.view import EntityView, EntityStartupView
-from cubicweb.selectors import (is_instance, has_related_entities, none_rset,
-                                anonymous_user, authenticated_user,
+from cubicweb.predicates import (is_instance, has_related_entities, none_rset,
                                 score_entity, paginated_rset)
 from cubicweb import tags
-from cubicweb.web import component, uicfg
-from cubicweb.web.views import tabs, baseviews, tableview, navigation
+from cubicweb.web import component
+from cubicweb.web.views import uicfg, tabs, baseviews, tableview, navigation
 
 from cubes.tracker.views import fixed_orderby_rql
 
 _pvdc = uicfg.primaryview_display_ctrl
-_pvdc.tag_attribute(('Project', 'summary'), {'showlabel': False})
 _pvdc.tag_attribute(('Project', 'description'), {'showlabel': False})
 
 # primary view and tabs ########################################################
@@ -31,14 +29,14 @@ _pvdc.tag_attribute(('Project', 'description'), {'showlabel': False})
 class ProjectPrimaryView(tabs.TabbedPrimaryView):
     __select__ = is_instance('Project')
 
-    tabs = [_('projectinfo_tab'), _('projectroadmap_tab'), _('projecttickets_tab'),
-            'activitystream']
+    tabs = [_('projectinfo_tab'), _('projecttickets_tab'), 'activitystream']
     default_tab = 'projectinfo_tab'
 
 
 # configure projectinfotab
 _pvs = uicfg.primaryview_section
 _pvs.tag_attribute(('Project', 'name'), 'hidden')
+_pvs.tag_attribute(('Project', 'summary'), 'hidden')
 # XXX keep '*', not Project to match other target types added in eg forge
 _pvs.tag_object_of(('*', 'version_of', 'Project'), 'hidden')
 _pvs.tag_object_of(('*', 'concerns', 'Project'), 'hidden')
@@ -54,18 +52,6 @@ class ProjectInfoTab(tabs.PrimaryTab):
     title = None # should not appear in possible views
 
 
-class ProjectRoadmapTab(EntityView):
-    """display the latest published version and in preparation version"""
-    __regid__ = 'projectroadmap_tab'
-    __select__ = (anonymous_user() & is_instance('Project') &
-                  has_related_entities('version_of', 'object'))
-
-    title = None # should not appear in possible views
-
-    def cell_call(self, row, col):
-        self.cw_rset.get_entity(row, col).view('roadmap', w=self.w)
-
-
 class ProjectTicketsTab(EntityView):
     __regid__ = 'projecttickets_tab'
     __select__ = is_instance('Project')
@@ -161,12 +147,14 @@ class ProjectRoadmapComponent(component.EntityCtxComponent):
     """display the latest published version and in preparation version"""
     __regid__ = 'roadmap'
     __select__ = (component.EntityCtxComponent.__select__ &
-                  authenticated_user() & is_instance('Project') &
+                  is_instance('Project') &
                   has_related_entities('version_of', 'object'))
     context = 'navcontenttop'
     order = 10
 
     def render_body(self, w):
+        if getattr(self.entity, 'summary', None):
+            w(u'<div id="summary">%s</div>' % xml_escape(self.entity.summary))
         self.entity.view('roadmap', w=w)
 
 
@@ -200,6 +188,7 @@ class ProjectRoadmapView(EntityView):
            'X eid %(x)s')
 
     def cell_call(self, row, col):
+        self._cw.add_css('cubes.tracker.css')
         self.w(u'<div class="section">')
         entity = self.cw_rset.get_entity(row, col)
         currentversion = entity.latest_version()
@@ -212,7 +201,7 @@ class ProjectRoadmapView(EntityView):
         if rset:
             self.wview('ic_progress_table_view', rset)
         allversionsrql = entity.cw_related_rql('version_of', 'object') % {'x': entity.eid}
-        self.w('<a href="%s">%s</a>'
+        self.w('<div class="roadmap-see-all"> <a class="icon-progress-3" href="%s">%s</a></div>'
                % (xml_escape(self._cw.build_url(vid='list', rql=allversionsrql)),
                   self._cw._('view all versions')))
         self.w(u'</div>')
@@ -326,13 +315,11 @@ class SubscribeToReleasesComponent(component.EntityCtxComponent):
 
     def render_body(self, w):
         label = self._cw._(u'Subscribe to project releases')
-        logo = u'<img src="%s" alt="%s"/>' % (
-            self._cw.uiprops['RSS_LOGO_16'], label)
         rql = 'Any V, VN ORDERBY VN DESC WHERE V version_of P, P eid %s, ' \
               'V in_state S, S name "published", V num VN' % self.entity.eid
         # XXX <project>/versions/rss ?
         url = self._cw.build_url('view', vid='rss', rql=rql)
-        w(u'<a href="%s" title="%s" class="toolbarButton">%s</a>' % (
-            xml_escape(url), label, logo))
+        w(u'<a href="%s" title="%s" class="toolbarButton icon-rss"></a>' % (
+            xml_escape(url), xml_escape(label) ))
 
 
