@@ -14,7 +14,7 @@ from cubicweb.predicates import (objectify_predicate, is_instance, multi_lines_r
                                  score_entity)
 from cubicweb import tags, uilib
 from cubicweb.web import component, action
-from cubicweb.web.views import uicfg, primary, baseviews, ibreadcrumbs
+from cubicweb.web.views import uicfg, primary, baseviews, ibreadcrumbs, ajaxcontroller
 
 _pvs = uicfg.primaryview_section
 
@@ -231,12 +231,25 @@ class TicketMoveToNextVersionActions(TicketAction):
 
     def url(self, version):
         if self.cw_row is None:
-            eids = [str(row[self.cw_col or 0]) for row in self.cw_rset]
+            eids = [row[self.cw_col or 0] for row in self.cw_rset]
         else:
-            eids = [str(self.cw_rset[self.cw_row][self.cw_col or 0])]
-        rql = 'SET X done_in V WHERE X eid IN(%s), V eid %%(v)s' % ','.join(eids)
-        msg = self._cw._('tickets moved to version %s') % version.num
-        return self._cw.user_rql_callback((rql, {'v': version.eid}, 'v'), msg)
+            eids = [self.cw_rset[self.cw_row][self.cw_col or 0]]
+        jscall = uilib.js.cw.utils.callAjaxFuncThenReload('movetoversion', version.eid, eids)
+        return u'javascript: %s' % jscall
+
+
+@ajaxcontroller.ajaxfunc
+def movetoversion(self, versioneid, ticketeids):
+    # validate input
+    int(versioneid)
+    [int(eid) for eid in ticketeids]
+    # now we can actually use it
+    ticketeids = ','.join(str(eid) for eid in ticketeids)
+    self._cw.execute('SET X done_in V WHERE X eid IN(%s), V eid %%(v)s' % ticketeids,
+                     {'v': versioneid})
+    version = self._cw.entity_from_eid(versioneid)
+    msg = self._cw._('tickets moved to version %s') % version.num
+    return msg
 
 
 class TicketCSVExportAction(TicketAction):
@@ -244,7 +257,7 @@ class TicketCSVExportAction(TicketAction):
     __select__ = multi_lines_rset() & TicketAction.__select__
 
     title = _('csv export')
-
+    icon = 'icon-export'
     def url(self):
         return self._cw.build_url('view', rql=self.cw_rset.printable_rql(),
                               vid='csvexport')
